@@ -6,11 +6,10 @@ use warnings;
 
 use Games::Dice 'roll';
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 sub init {
     my ($bot) = @_;
-    my $expr = Math::Expression->new( PrintErrFunc => sub {} );
 
     $bot->hook(
         {
@@ -40,7 +39,7 @@ Bot::IRC::X::Dice - Bot::IRC plugin for dice rolling
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Dice.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Dice)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Dice/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Dice)
@@ -59,6 +58,8 @@ version 1.02
 This L<Bot::IRC> plugin provides the means for the bot to perform simulated
 dice rolls.
 
+    roll <dice expression like "2d6+2">
+
 =head1 SEE ALSO
 
 You can look for additional information at:
